summaryrefslogtreecommitdiff
path: root/src/lib
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2019-02-14 22:10:35 +0000
committerCarl Hetherington <cth@carlh.net>2019-02-14 22:10:35 +0000
commit7d1c30d17b3494e07fd32dd34cd4806006e725dd (patch)
treeed2c22866ca1565785c3ea9b8802d8034fb4b5ee /src/lib
parent6a1837228d90b49bba78c8822b989463fb4dfb0d (diff)
Player log file -> player activity log file.
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/config.cc14
-rw-r--r--src/lib/config.h19
2 files changed, 20 insertions, 13 deletions
diff --git a/src/lib/config.h b/src/lib/config.h
index e3a34aed3..5ae14ebda 100644
--- a/src/lib/config.h
+++ b/src/lib/config.h
@@ -484,8 +484,8 @@ public:
return _respect_kdm_validity_periods;
}
- boost::optional<boost::filesystem::path> player_log_file () const {
- return _player_log_file;
+ boost::optional<boost::filesystem::path> player_activity_log_file () const {
+ return _player_activity_log_file;
}
boost::optional<boost::filesystem::path> player_content_directory () const {
@@ -940,15 +940,15 @@ public:
maybe_set (_respect_kdm_validity_periods, r);
}
- void set_player_log_file (boost::filesystem::path p) {
- maybe_set (_player_log_file, p);
+ void set_player_activity_log_file (boost::filesystem::path p) {
+ maybe_set (_player_activity_log_file, p);
}
- void unset_player_log_file () {
- if (!_player_log_file) {
+ void unset_player_activity_log_file () {
+ if (!_player_activity_log_file) {
return;
}
- _player_log_file = boost::none;
+ _player_activity_log_file = boost::none;
changed ();
}
@@ -1227,7 +1227,10 @@ private:
PlayerMode _player_mode;
int _image_display;
bool _respect_kdm_validity_periods;
- boost::optional<boost::filesystem::path> _player_log_file;
+ /** Log file containing things the player does (e.g. started, stopped, loaded
+ playlist etc.) Does not contain debugging information.
+ */
+ boost::optional<boost::filesystem::path> _player_activity_log_file;
/** A directory containing DCPs whose contents are presented to the user
in the dual-screen player mode. DCPs on the list can be loaded
for playback.
diff --git a/src/lib/config.cc b/src/lib/config.cc
index 99ed74b29..ac7cf7e76 100644
--- a/src/lib/config.cc
+++ b/src/lib/config.cc
@@ -168,7 +168,7 @@ Config::set_defaults ()
_player_mode = PLAYER_MODE_WINDOW;
_image_display = 0;
_respect_kdm_validity_periods = true;
- _player_log_file = boost::none;
+ _player_activity_log_file = boost::none;
_player_content_directory = boost::none;
_player_playlist_directory = boost::none;
_player_kdm_directory = boost::none;
@@ -550,7 +550,11 @@ try
_image_display = f.optional_number_child<int>("ImageDisplay").get_value_or(0);
_respect_kdm_validity_periods = f.optional_bool_child("RespectKDMValidityPeriods").get_value_or(true);
- _player_log_file = f.optional_string_child("PlayerLogFile");
+ /* PlayerLogFile is old name */
+ _player_activity_log_file = f.optional_string_child("PlayerLogFile");
+ if (!_player_activity_log_file) {
+ _player_activity_log_file = f.optional_string_child("PlayerActivityLogFile");
+ }
_player_content_directory = f.optional_string_child("PlayerContentDirectory");
_player_playlist_directory = f.optional_string_child("PlayerPlaylistDirectory");
_player_kdm_directory = f.optional_string_child("PlayerKDMDirectory");
@@ -989,9 +993,9 @@ Config::write_config () const
root->add_child("ImageDisplay")->add_child_text(raw_convert<string>(_image_display));
/* [XML] RespectKDMValidityPeriods 1 to refuse to use KDMs that are out of date, 0 to ignore KDM dates. */
root->add_child("RespectKDMValidityPeriods")->add_child_text(_respect_kdm_validity_periods ? "1" : "0");
- if (_player_log_file) {
- /* [XML] PlayerLogFile Filename to use for player logs */
- root->add_child("PlayerLogFile")->add_child_text(_player_log_file->string());
+ if (_player_activity_log_file) {
+ /* [XML] PlayerLogFile Filename to use for player activity logs (e.g starting, stopping, playlist loads) */
+ root->add_child("PlayerActivityLogFile")->add_child_text(_player_activity_log_file->string());
}
if (_player_content_directory) {
/* [XML] PlayerContentDirectory Filename to use for player content in the dual-screen mode. */